@@ -50,8 +50,8 @@ downloads, installation and source code.
 
 __Conventions__  = 'CF-1.5'
 __author__       = 'David Hassell'
-__date__         = '2016-08-23'
-__version__      = '1.2.3'
+__date__         = '2016-09-09'
+__version__      = '1.3.1'
 
 from distutils.version import StrictVersion
 import imp
@@ -98,7 +98,7 @@ from .write                import write
 from .utils                import Dict #List, Dict
 from .units                import Units
 from .cfdatetime           import Datetime, dt
-from .timeduration         import TimeDuration, Y, M, D, h, m, s
+from .timeduration         import TimeDuration, Y, M, D, h, m, s, fix_reftime_units
 from .data.data            import Data
 from .aggregate            import aggregate
 from .query                import (Query, lt, le, gt, ge, eq, ne, contain,
