@@ -640,7 +640,7 @@ array([-31., -30., -29., -28., -27.])
                     _calendar = _default_calendar
                 else:
                     _calendar = _canonical_calendar[calendar.lower()]
-                
+
                 units_split = units.split(' since ')
                 unit        = units_split[0].strip()
 
@@ -2216,9 +2216,10 @@ The units of the time value are described by the `!unit_string` and
 See `netCDF4.netcdftime.utime.num2date` for details.
 
 In addition to `netCDF4.netcdftime.utime.num2date`, this method
-handles units of months and years.
+handles units of months and years as defined by Udunits, ie. 1 year =
+365.242198781 days, 1 month = 365.242198781/12 days.
 
-'''
+        '''
         units = self.units
         unit_string = self.unit_string
 
@@ -2231,6 +2232,15 @@ handles units of months and years.
             # Convert years to days
             unit_string = unit_string.replace(units, 'days', 1)
             time_value = numpy_array(time_value)*365.242198781
+        elif units == 'calendar_month':
+            # Convert months to days
+            unit_string = unit_string.replace(units, 'days', 1)
+            time_value = numpy_array(time_value)*365.242198781/12
+        elif units == 'calendar_year':
+            # Convert months to days
+            unit_string = unit_string.replace(units, 'days', 1)
+            time_value = numpy_array(time_value)*365.242198781/12
+
 
         u = _netCDF4_netcdftime_utime(unit_string, self.calendar)        
         return u.num2date(time_value)
