@@ -3,6 +3,7 @@ import numpy
 import cf
 import unittest
 import inspect
+import datetime
 
 class FieldTest(unittest.TestCase):
     filename = os.path.join(os.path.dirname(os.path.abspath(__file__)),
@@ -397,11 +398,13 @@ class FieldTest(unittest.TestCase):
         g = f.mask_invalid(i=True)
         g = cf.FieldList(f).mask_invalid(i=True)
     #--- End: def
-    
+        
 #--- End: class
 
 if __name__ == '__main__':
-    print 'cf-python version:'     , cf.__version__
-    print 'cf-python path:'        , os.path.abspath(cf.__file__)
+#    print 'cf-python version:'     , cf.__version__
+#    print 'cf-python path:'        , os.path.abspath(cf.__file__)
+    print 'Run date:', datetime.datetime.now()
+    cf.ENVIRONMENT()
     print''
     unittest.main(verbosity=2)
